==> jc-1.4.0.tar.gz: polyglot/visit/NodeScrambler__24FirstPass.h <==
// public class polyglot.visit.NodeScrambler$FirstPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9a5f2de99abb81e polyglot_visit_NodeScrambler__24FirstPass
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_NodeScrambler__24FirstPass_H_
#define _JC_polyglot_visit_NodeScrambler__24FirstPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeScrambler$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs	_jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs	_jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$refs	_jc_polyglot_visit_NodeScrambler__24FirstPass$refs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs	_jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object	_jc_polyglot_visit_NodeScrambler__24FirstPass$object;

typedef const struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods	_jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods;
typedef const struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtable	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtable;
typedef const struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtype	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtype;

// Constructors
extern void _jc_polyglot_visit_NodeScrambler__24FirstPass$method$_init$6a924c499a63e3c9(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_polyglot_visit_NodeScrambler$object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_NodeScrambler__24FirstPass$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_NodeScrambler__24FirstPass$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_NodeScrambler__24FirstPass$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_NodeScrambler__24FirstPass$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods	polyglot_visit_NodeScrambler__24FirstPass;
};

// Vtype
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtype {
	_jc_type			type;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs {
	struct _jc_polyglot_visit_NodeScrambler$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$refs {
    _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs	polyglot_visit_NodeScrambler__24FirstPass;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs	polyglot_visit_NodeScrambler__24FirstPass;
};

// Object instance structure
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object {
	_jc_polyglot_visit_NodeScrambler__24FirstPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtype	*vtype;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_NodeScrambler__24FirstPass$vtype _jc_polyglot_visit_NodeScrambler__24FirstPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_NodeScrambler__24FirstPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_NodeScrambler__24FirstPass$class_object;

#endif	/* _JC_polyglot_visit_NodeScrambler__24FirstPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/NodeScrambler__24FirstPass.h <==
// public class polyglot.visit.NodeScrambler$FirstPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9a5f2de99abb81e polyglot_visit_NodeScrambler__24FirstPass
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_NodeScrambler__24FirstPass_H_
#define _JC_polyglot_visit_NodeScrambler__24FirstPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeScrambler$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs	_jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs	_jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$refs	_jc_polyglot_visit_NodeScrambler__24FirstPass$refs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs	_jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object	_jc_polyglot_visit_NodeScrambler__24FirstPass$object;

typedef const struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods	_jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods;
typedef const struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtable	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtable;
typedef const struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtype	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtype;

// Constructors
extern void _jc_polyglot_visit_NodeScrambler__24FirstPass$method$_init$6a924c499a63e3c9(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_polyglot_visit_NodeScrambler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_NodeScrambler__24FirstPass$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_NodeScrambler__24FirstPass$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_NodeScrambler__24FirstPass$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_NodeScrambler__24FirstPass$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$vmethods	polyglot_visit_NodeScrambler__24FirstPass;
};

// Vtype
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$vtype {
	_jc_type			type;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs {
	struct _jc_polyglot_visit_NodeScrambler$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$refs {
    _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_refs	polyglot_visit_NodeScrambler__24FirstPass;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_NodeScrambler__24FirstPass$sub_nonrefs	polyglot_visit_NodeScrambler__24FirstPass;
};

// Object instance structure
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object {
	_jc_polyglot_visit_NodeScrambler__24FirstPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$vtype	*vtype;
	_jc_polyglot_visit_NodeScrambler__24FirstPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_NodeScrambler__24FirstPass$vtype _jc_polyglot_visit_NodeScrambler__24FirstPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_NodeScrambler__24FirstPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_NodeScrambler__24FirstPass$class_object;

#endif	/* _JC_polyglot_visit_NodeScrambler__24FirstPass_H_ */
